# torchcs

Compressed Sensing in PyTorch.


You can install and test ``torchcs`` by:

```bash
pip install torchcs
import torchcs as tc
print(tc.__version__)
```

Please see [torchcs's documentation](http://iridescent.ink/torchcs) for using details.

